
(_api_mie)=
# Mie

## Linearized Mie
```{eval-rst}
.. autoclass:: sasktran2.mie.LinearizedMie

```

## Output Data structures
```{eval-rst}
.. autoclass:: sasktran2.mie.MieOutput
.. autoclass:: sasktran2.mie.MieData

```
